==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Izberi črto, lok ali krog</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Razdalja:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Število:</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Vzpo&amp;redno (z razdaljo)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Odmik (z razdaljo)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Odmik črte, loka, kroga ali elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Nariši vzporednico obstoječi črti ali kocentrični lok, krog</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Izberi črto, lok ali krog</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Razdalja:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Število:</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Vzpo&amp;redno (z razdaljo)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Odmik (z razdaljo)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Odmik črte, loka, kroga ali elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Nariši vzporednico obstoječi črti ali kocentrični lok, krog</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Polmer je padel pod 0,0 po %1 kocentričnimi krogi.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Polmer je padel pod 0,0 po %1 kocentričnimi loki.</translation>
    </message>
</context>
</TS>
